# Pipeline with id \[\] does not exist

**URL:** <https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476>\
**Category:** Elasticsearch\
**Created:** [December 23, 2020, 11:55am UTC](https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476 "2020-12-23T11:55:37Z")\
**Posts on this page:** 14\
**Page:** 1

<div class="post-metadata">

**Author:** ![Atul\_Chadha](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/atul_chadha/32/75469_2.png) [@Atul\_Chadha](https://discuss.elastic.co/u/Atul_Chadha)\
**Post date:** [December 23, 2020, 11:55am UTC](https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476/1 "2020-12-23T11:55:37Z")

</div>

There are few references to this problem already here but none provide resolution, I am getting the below error on 7.6.2 and i do see the pipeline when i run the GET API call

```
 {
      "index" : "xxxxxxxxxx-2020.45-reindex",
      "type" : "_doc",
      "id" : "AXWZCt_d8Su-BwbMoSsb",
      "cause" : {
        "type" : "illegal_argument_exception",
        "reason" : "pipeline with id [mypipe] does not exist"
      },
      "status" : 400

```

Any suggestions what can be tried to fix this ?

---

<div class="post-metadata">

**Author:** ![dadoonet](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/dadoonet/32/137187_2.png) [@dadoonet](https://discuss.elastic.co/u/dadoonet)\
**Post date:** [December 23, 2020, 12:08pm UTC](https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476/2 "2020-12-23T12:08:15Z")

</div>

There is no pipeline named `mypipe`. That's the only thing we can tell from what you shared.

What is the output of:

```
GET /_ingest/pipeline/mypipe

```

Please [read this](https://discuss.elastic.co/t/about-the-elasticsearch-category/21) about how to format.

---

<div class="post-metadata">

**Author:** ![Atul\_Chadha](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/atul_chadha/32/75469_2.png) [@Atul\_Chadha](https://discuss.elastic.co/u/Atul_Chadha)\
**Post date:** [December 24, 2020, 9:09am UTC](https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476/3 "2020-12-24T09:09:56Z")

</div>

Hi David,

Appreciate the response, the output is shared below

```
{
  "mypipe" : {
    "description" : "ELK Migration",
    "processors" : [
      {
        "rename" : {
          "field" : "host",
          "target_field" : "host.name"
        }
      }
    ]
  }
}
```

---

<div class="post-metadata">

**Author:** ![dadoonet](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/dadoonet/32/137187_2.png) [@dadoonet](https://discuss.elastic.co/u/dadoonet)\
**Post date:** [December 24, 2020, 11:24am UTC](https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476/4 "2020-12-24T11:24:19Z")

</div>

Could you explain exactly what you did?

Could you provide a full recreation script as described in [About the Elasticsearch category](https://discuss.elastic.co/t/about-the-elasticsearch-category/21). It will help to better understand what you are doing. Please, try to keep the example as simple as possible.

A full reproduction script is something anyone can copy and paste in Kibana dev console, click on the run button to reproduce your use case. It will help readers to understand, reproduce and if needed fix your problem. It will also most likely help to get a faster answer.

---

<div class="post-metadata">

**Author:** ![Atul\_Chadha](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/atul_chadha/32/75469_2.png) [@Atul\_Chadha](https://discuss.elastic.co/u/Atul_Chadha)\
**Post date:** [December 24, 2020, 12:09pm UTC](https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476/5 "2020-12-24T12:09:08Z")

</div>

Thank you for the prompt responses, i used the below two snippets to create a pipeline and then force a reindex (old to new cluster) using the above pipeline.

I have removed sensitive info

```
curl -uxxxxxx:xxxxxx -X PUT "#########:9200/_ingest/pipeline/mypipe?pretty" -H 'Content-Type: application/json' -d'
{
  "description" : "ELK Migration",
  "processors" : [
    {
      "rename": {
        "field": "host",
        "target_field": "host.name"
      }
    }
  ]
}
'

curl -uxxxxxx:xxxxxxx -X POST "#########:9200/_reindex?pretty=true" -H 'Content-Type:application/json' -d'
{
  "source": {
    "remote": {"host": "http://#########:9200", "username": "elastic", "password": "xxxxxx"},
    "index": "inf_cmk_log-2020.45",
  "dest":
    "index": "inf_cmk_log-2020.45-reindex",
    "pipeline": "mypipe",
	"op_type": "create",
  }
}
'
```

---

<div class="post-metadata">

**Author:** ![dadoonet](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/dadoonet/32/137187_2.png) [@dadoonet](https://discuss.elastic.co/u/dadoonet)\
**Post date:** [December 24, 2020, 12:42pm UTC](https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476/6 "2020-12-24T12:42:03Z")

</div>

On which cluster did you run the 2 commands?  
Could you replace the `xxxxx` values with `cluster1` `cluster2` so it's more obvious?

---

<div class="post-metadata">

**Author:** ![Atul\_Chadha](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/atul_chadha/32/75469_2.png) [@Atul\_Chadha](https://discuss.elastic.co/u/Atul_Chadha)\
**Post date:** [December 24, 2020, 12:53pm UTC](https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476/7 "2020-12-24T12:53:52Z")

</div>

> [@Atul\_Chadha](#):
>
> ```auto
> curl -uxxxxxx:xxxxxxx -X POST "#########:9200/_reindex?pretty=true" -H 'Content-Type:application/json' -d'
> {
> "source": {
> "remote": {"host": "http://#########:9200", "username": "elastic", "password": "xxxxxx"},
> "index": "inf_cmk_log-2020.45",
> "dest":
> "index": "inf_cmk_log-2020.45-reindex",
> "pipeline": "mypipe",
> "op_type": "create",
> }
> }
> '
> 
> ```

Sorry About that !

```
curl -uelastic:xxxxxx -X PUT "clu01:9200/_ingest/pipeline/mypipe?pretty" -H 'Content-Type: application/json' -d'{
  "description" : "ELK Migration",
  "processors" : [
    {
      "rename": {
        "field": "host",
        "target_field": "host.name"
      }
    }
  ]
}
'

curl -XPOST -uelastic:xxxxxx "clu01:9200/_reindex?wait_for_completion=true&pretty=true" -H 'Content-Type:application/json' -d'
{
  "source": {
    "remote": {"host": "http://clu02:9200", "username": "elastic", "password": "xxxxxx"},
    "index": "inf_cmk_log-2020.45",
  "dest":
    "index": "inf_cmk_log-2020.45-reindex",
    "pipeline": "mypipe",
	"op_type": "create",
  }
}
'

```

---

<div class="post-metadata">

**Author:** ![dadoonet](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/dadoonet/32/137187_2.png) [@dadoonet](https://discuss.elastic.co/u/dadoonet)\
**Post date:** [December 24, 2020, 3:32pm UTC](https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476/8 "2020-12-24T15:32:43Z")

</div>

What is the full output of:

```
GET /_ingest/pipeline/

```

Do not modify the content please.

---

<div class="post-metadata">

**Author:** ![Atul\_Chadha](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/atul_chadha/32/75469_2.png) [@Atul\_Chadha](https://discuss.elastic.co/u/Atul_Chadha)\
**Post date:** [December 24, 2020, 3:46pm UTC](https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476/9 "2020-12-24T15:46:50Z")

</div>

> [@Atul\_Chadha](#):
>
> ```auto
> curl -uxxxxxx:xxxxxx -X PUT "#########:9200/_ingest/pipeline/mypipe?pretty" -H 'Content-Type: application/json' -d'
> {
> "description" : "ELK Migration",
> "processors" : [
> {
> "rename": {
> "field": "host",
> "target_field": "host.name"
> }
> }
> ]
> }
> '
> 
> ```

```
Hope this helps

{"xpack_monitoring_6":{"description":"This pipeline upgrades documents from the older version of the Monitoring API to the newer version (7) by fixing breaking changes in those older documents before they are indexed from the older version (6).","version":7000199,"processors":[{"script":{"source":"ctx._type = null"}},{"gsub":{"field":"_index","pattern":"(.monitoring-\\w+-)6(-.+)","replacement":"$17$2"}}]},"xpack_monitoring_7":{"description":"This is a placeholder pipeline for Monitoring API version 7 so that future versions may fix breaking changes.","version":7000199,"processors":[]},"mypipe":{"description":"ELK Migration","processors":[{"rename":{"field":"host","target_field":"host.name"}}]}}[root@clu01 ~]#

```

---

<div class="post-metadata">

**Author:** ![dadoonet](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/dadoonet/32/137187_2.png) [@dadoonet](https://discuss.elastic.co/u/dadoonet)\
**Post date:** [December 24, 2020, 5:17pm UTC](https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476/10 "2020-12-24T17:17:33Z")

</div>

Which elastic version are you using on both clusters?

Could you run on clu01:

```
DELETE test 
PUT test/_doc/1?pipeline=mypipe
{ "foo": "bar" }

```

?

---

<div class="post-metadata">

**Author:** ![Atul\_Chadha](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/atul_chadha/32/75469_2.png) [@Atul\_Chadha](https://discuss.elastic.co/u/Atul_Chadha)\
**Post date:** [December 24, 2020, 5:21pm UTC](https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476/11 "2020-12-24T17:21:15Z")

</div>

There is a difference, the old cluster is on 5.6.3 and new one is 7.6.2

---

<div class="post-metadata">

**Author:** ![Atul\_Chadha](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/atul_chadha/32/75469_2.png) [@Atul\_Chadha](https://discuss.elastic.co/u/Atul_Chadha)\
**Post date:** [December 24, 2020, 5:22pm UTC](https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476/12 "2020-12-24T17:22:43Z")

</div>

will test the delete and get back to you..

---

<div class="post-metadata">

**Author:** ![Atul\_Chadha](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/atul_chadha/32/75469_2.png) [@Atul\_Chadha](https://discuss.elastic.co/u/Atul_Chadha)\
**Post date:** [December 26, 2020, 12:53pm UTC](https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476/13 "2020-12-26T12:53:05Z")

</div>

Really not sure how however this is resolved by a server reboot. I was able to use the pipeline, @dadoonet Appreciate your expertise !

---

<div class="post-metadata">

**Author:** ![system](https://us1.discourse-cdn.com/elastic/original/3X/1/a/1ac57faf039f6b580b3f104ef42a2a89e41014de.png) [@system](https://discuss.elastic.co/u/system)\
**Post date:** [January 23, 2021, 12:53pm UTC](https://discuss.elastic.co/t/pipeline-with-id-does-not-exist/259476/14 "2021-01-23T12:53:06Z")

</div>

This topic was automatically closed 28 days after the last reply. New replies are no longer allowed.
